PdaRfidScanner class
Main class for working with PDA scanner and RFID
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
scanStream
→ Stream<
ScanResult> -
Get a stream of scan results
no setter
Static Methods
-
disableRfid(
) → Future< bool> - Disable RFID module
-
enableRfid(
) → Future< bool> - Enable RFID module (turns off barcode scanner if active)
-
getCurrentMode(
) → Future< ScanType> - Get current operation mode (barcode/rfid/unknown)
-
getPlatformVersion(
) → Future< String?> - Get platform version
-
isRfidActive(
) → Future< bool> - Check if RFID module is active
-
isScannerActive(
) → Future< bool> - Check if barcode scanner is active
-
powerOff(
) → Future< String> - For backward compatibility with previous library version Power off (RFID module)
-
powerOn(
) → Future< String> - For backward compatibility with previous library version Power on (RFID module)
-
scanStart(
) → Future< String> - For backward compatibility with previous library version Start scanning (barcode scanner)
-
setAutoRestartScan(
bool enable) → Future< bool> - Set auto-restart option for barcode scanning When enabled, scanner will automatically restart after each scan
-
startBarcodeScan(
) → Future< bool> - Start barcode scanning (turns off RFID if active)
-
stopBarcodeScan(
) → Future< bool> - Stop barcode scanning